@@ -96,10 +96,11 @@ options:
             description:
                 type: str
                 description: Description.
-            enabled options:
+            enabled_options:
+                aliases: ['enabled options']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to enabled_options. Enabled options.
+                description: Enabled options.
                 choices:
                     - 'none'
                     - 'dns'
@@ -117,10 +118,11 @@ options:
             oid:
                 type: int
                 description: Oid.
-            scope member:
+            scope_member:
+                aliases: ['scope member']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to scope_member. Scope member.
+                description: Scope member.
                 suboptions:
                     name:
                         type: str
@@ -139,6 +141,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -147,32 +150,31 @@ EXAMPLES = '''
     - name: System template adom
       fortinet.fortimanager.fmgr_pm_devprof_pkg:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         pkg_path: <your own value>
         state: present # <value in [present, absent]>
         pm_devprof_pkg:
-          description: <string>
-          enabled_options:
-            - none
-            - dns
-            - ntp
-            - email
-            - admin
-            - snmp
-            - repmsg
-            - ftgd
-            - log
-          name: <string>
-          oid: <integer>
-          scope_member:
-            -
-              name: <string>
-              vdom: <string>
-          type: <value in [devprof]>
+          name: "your value" # Required variable, string
+          # description: <string>
+          # enabled_options:
+          #   - "none"
+          #   - "dns"
+          #   - "ntp"
+          #   - "email"
+          #   - "admin"
+          #   - "snmp"
+          #   - "repmsg"
+          #   - "ftgd"
+          #   - "log"
+          # oid: <integer>
+          # scope_member:
+          #   - name: <string>
+          #     vdom: <string>
+          # type: <value in [devprof]>
 '''
 
 RETURN = '''
@@ -216,21 +218,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/devprof/adom/{adom}/{pkg_path}'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/devprof/adom/{adom}/{pkg_path}'
-    ]
-
     url_params = ['adom', 'pkg_path']
     module_primary_key = 'name'
     module_arg_spec = {
@@ -251,7 +246,6 @@ def main():
                 'scope member': {'type': 'list', 'options': {'name': {'type': 'str'}, 'vdom': {'type': 'str'}}, 'elements': 'dict'},
                 'type': {'choices': ['devprof'], 'type': 'str'}
             }
-
         }
     }
 
@@ -260,14 +254,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'pm_devprof_pkg'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
