@@ -96,6 +96,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -104,16 +105,16 @@ EXAMPLES = '''
     - name: Send and receive JSON request to/from managed devices.
       fortinet.fortimanager.fmgr_sys_proxy_json:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         sys_proxy_json:
-          action: <value in [get, post, put, ...]>
-          payload: <dict>
-          resource: <string>
-          target: <list or string>
-          timeout: <integer>
+          # action: <value in [get, post, put, ...]>
+          # payload: <dict>
+          # resource: <string>
+          # target: <list or string>
+          # timeout: <integer>
 '''
 
 RETURN = '''
@@ -157,21 +158,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/sys/proxy/json'
     ]
-
-    perobject_jrpc_urls = [
-        '/sys/proxy/json/{json}'
-    ]
-
     url_params = []
     module_primary_key = None
     module_arg_spec = {
@@ -185,7 +179,6 @@ def main():
                 'target': {'type': 'list', 'elements': 'str'},
                 'timeout': {'v_range': [['7.0.1', '']], 'type': 'int'}
             }
-
         }
     }
 
@@ -199,9 +192,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('exec', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_exec(argument_specs=module_arg_spec)
+    fmgr.process_exec()
 
     module.exit_json(meta=module.params)
 
